from typing import Dict

def load_schema(schema_path: str) -> Dict: ...
def parse_schema(
    schema: str, expand: bool, _write_hint: bool, _force: bool
) -> Dict: ...
def fullname(schema: Dict) -> str: ...
def expand_schema(schema: Dict) -> Dict: ...
